summaryrefslogtreecommitdiff
path: root/src/components/policy/policy_regular/include/policy/cache_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/policy/policy_regular/include/policy/cache_manager.h')
-rw-r--r--src/components/policy/policy_regular/include/policy/cache_manager.h28
1 files changed, 18 insertions, 10 deletions
diff --git a/src/components/policy/policy_regular/include/policy/cache_manager.h b/src/components/policy/policy_regular/include/policy/cache_manager.h
index 39f9cc73cd..8c8f0c55c6 100644
--- a/src/components/policy/policy_regular/include/policy/cache_manager.h
+++ b/src/components/policy/policy_regular/include/policy/cache_manager.h
@@ -158,7 +158,8 @@ class CacheManager : public CacheManagerInterface {
* @brief Get cloud app policy information, all fields that aren't set for a
* given app will be filled with empty strings
* @param policy_app_id Unique application id
* @param endpoint Filled the endpoint used to connect to the cloud
* application
* @param certificate Filled with the certificate used to for creating a
* secure connection to the cloud application
@@ -166,17 +167,24 @@ class CacheManager : public CacheManagerInterface {
* reconnecting to the cloud app
* @param cloud_transport_type Filled with the transport type used by the
* cloud application (ex. "WSS")
- * @param cloud_transport_type Filled with the hybrid app preference for the
+ * @param hybrid_app_preference Filled with the hybrid app preference for the
* cloud application set by the user
- * @return true if the cloud app is enabled, false otherwise
*/
- virtual const bool GetCloudAppParameters(
- const std::string& policy_app_id,
- std::string& endpoint,
- std::string& certificate,
- std::string& auth_token,
- std::string& cloud_transport_type,
- std::string& hybrid_app_preference) const;
+ virtual void GetCloudAppParameters(const std::string& policy_app_id,
+ bool& enabled,
+ std::string& endpoint,
+ std::string& certificate,
+ std::string& auth_token,
+ std::string& cloud_transport_type,
+ std::string& hybrid_app_preference) const;
+
+ /**
+ * Initializes a new cloud application with default policies
+ * Then adds cloud specific policies
+ * @param app_id application id
+ * @return true if success
+ */
+ virtual void InitCloudApp(const std::string& policy_app_id);
/**
* @brief Enable or disable a cloud application in the HMI
@@ -158,7 +158,8 @@ class CacheManager : public CacheManagerInterface {
* given app will be filled with empty strings
* @param policy_app_id Unique application id
- * @param endpoint Filled the endpoint used to connect to the cloud
+ * @param enabled Whether or not the app is enabled
+ * @param endpoint Filled with the endpoint used to connect to the cloud
* application
* @param certificate Filled with the certificate used to for creating a